@@ -35,3 +35,17 @@ class SPI(ABC):
     @abstractmethod
     def read_byte(self, reg: int) -> int:
         pass
+
+
+class Serial(ABC):
+
+    def __init__(self, port: str, baudrates: int, timeout: float):
+        super().__init__()
+
+    @abstractmethod
+    def read_bytes(self) -> bytes:
+        pass
+
+    @abstractmethod
+    def write_bytes(self, data: bytes):
+        pass
